<!doctype style-sheet PUBLIC "-//James Clark//DTD DSSSL Style Sheet//EN">
;; $Id: page.dsl,v 1.1 1998/05/10 23:12:53 tkg Exp $

;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
;; 1. External procedures
;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
(define if-first-page
  (external-procedure "UNREGISTERED::James Clark//Procedure::if-first-page"))

(define if-front-page
  (external-procedure "UNREGISTERED::James Clark//Procedure::if-front-page"))

;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
;; 2. Unit definitions
;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
(define-unit pi (/ 1in 6))
(define-unit pt (/ 1in 72))

;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
;; 3. Page dimensions
;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
;; These setup the page size and other parameters

;; Horizontal dimension
(define %page-width% 15pi)
;; Vertical dimension
(define %page-height% 20pi)
;; Left margin
(define %left-margin% 2pi)
;; Right Margin
(define %right-margin% 2pi)
;; Space from top of page to top of body text
(define %top-margin% 4pi)
;; Space from bottom of page to bottom of body text
(define %bottom-margin% 4pi)
;; Space from top of page to top of header.  Should be less than %top-margin%
(define %header-margin% 3pi)
;; Space from bottom of page to bottom of footer.  Should be less than
;; %bottom-margin%
(define %footer-margin% 1pi)

;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
;; 4. Common procedures
;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
(define ($para$)
  (make paragraph
	quadding: 'justify
	font-size: 12pt
	font-family-name: "Arial"
	space-before: 12pt
	space-after: 12pt))

;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
;; 5. Styles
;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
(define footer-style
  (style
   font-size: 9pt
   font-family-name: "Arial"))

;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
;; 6. Header and Footer procedures
;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
;; These procedures may be referenced as parameters to the
;; generic-page-sequence procedure that we are using to setup our
;; page.

;; footer-page-number
;; Just the page number
(define (footer-page-number)
  (make sequence
	use: footer-style
	(page-number-sosofo)))

;; verbose-footer-page-number
;; Page number in "Page nnn" format
(define (verbose-footer-page-number)
  (make sequence
	use: footer-style
	(literal "Page ")
	(page-number-sosofo)))

;; chapter-number-page-number
;; Include the chapter number in the page number, e.g. "1-1"
(define (chapter-number-page-number)
  (make sequence
	use: footer-style
	(literal
	 (string-append
	  (number->string
	   (child-number))
	  "\en-dash"))
	(page-number-sosofo)))

;; book-title
;; The book title
(define (book-title)
  (make sequence
	use: footer-style
	(with-mode header-title
		   (process-node-list
		    (select-elements
		     (children
		      (ancestor "BOOK"))
		     "TITLE")))))

;; my-title
;; Just the title of the current element
(define (my-title)
  (make sequence
	use: footer-style
	(with-mode header-title
		   (process-matching-children "TITLE"))))

;; chapter-number-title
;; The chapter number plus the chapter title
(define (chapter-number-title)
  (make sequence
	use: footer-style
	(literal
	 (string-append
	  "Chapter "
	  (number->string
	   (child-number))
	  ": "))
	(with-mode header-title
		   (process-matching-children "TITLE"))))

;; graphic
;; Just a graphic, just to prove we can
(define (graphic)
  (make external-graphic
	entity-system-id: "image1.gif"
	display?: #f))

;; Used when getting titles for use in headers
(mode header-title
      ;; Hierarchy Name: TITLE
      ;;
      ;; This could be the title of the book or of a chapter
      (element TITLE
	       (process-children)))

;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
;; 7. "generic-page-sequence" procedure definition
;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
;; This is the procedure we are using to make our simple-page-sequence
;; flow objects.  All of the element construction rules that want to
;; change the header or footer use this procedure and supply zero or
;; more of the pre-defined header and footer procedures for the
;; appropriate slots in the header and footer.  If any slots aren't
;; filled, they default to (empty-sosofo).
;;
;; The advantage of this over using a simple-page-sequence in each of
;; those element construction rules is that we only do it once, and
;; this procedure takes care of swapping left and right on recto and
;; verso pages and suppressing headings on the first page of the
;; simeple-page-sequence.
(define (generic-page-sequence
	 #!key
	 (inside-header (empty-sosofo))
	 (center-header (empty-sosofo))
	 (outside-header (empty-sosofo))
	 (inside-footer (empty-sosofo))
	 (center-footer (empty-sosofo))
	 (outside-footer (empty-sosofo))
	 (children (process-children)))
  (make simple-page-sequence
	page-width: %page-width%
	page-height: %page-height%
	left-margin: %left-margin%
	right-margin: %right-margin%
	top-margin: %top-margin%
	bottom-margin: %bottom-margin%
	header-margin: %header-margin%
	footer-margin: %footer-margin%
	left-footer: (if-front-page inside-footer
				    outside-footer)
	center-footer: center-footer
	right-footer: (if-front-page outside-footer
				     inside-footer)
	left-header: (if-first-page
		      (empty-sosofo)
		      (if-front-page inside-header
				     outside-header))
	center-header: (if-first-page
		       (empty-sosofo)
		       center-header)
	right-header: (if-first-page
		       (empty-sosofo)
		       (if-front-page outside-header
				      inside-header))
	children))

;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
;; 8. Element Construction Rules
;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;

;; BOOK element
(element BOOK
	 (generic-page-sequence
	  outside-footer: (verbose-footer-page-number)
	  outside-header: (my-title)))

;; TITLE element
(element TITLE
	 ($para$))

;; PARAGRAPH element
(element PARA
	 ($para$))

